mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH][next] samples/hid: Fix spelling mistake "wihout" -> "without"
@ 2022-11-16  9:39 Colin Ian King
  2022-11-16 10:32 ` Benjamin Tissoires
  2022-11-21 21:12 ` Jiri Kosina
  0 siblings, 2 replies; 3+ messages in thread
From: Colin Ian King @ 2022-11-16  9:39 UTC (permalink / raw)
  To: Jiri Kosina, Benjamin Tissoires, linux-input
  Cc: kernel-janitors, linux-kernel

There is a spelling mistake in a comment and a usage message. Fix them.

Signed-off-by: Colin Ian King <colin.i.king@gmail.com>
---
 samples/hid/hid_surface_dial.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/samples/hid/hid_surface_dial.c b/samples/hid/hid_surface_dial.c
index bceea53d39b0..4bc97373a708 100644
--- a/samples/hid/hid_surface_dial.c
+++ b/samples/hid/hid_surface_dial.c
@@ -4,7 +4,7 @@
  * This program will morph the Microsoft Surface Dial into a mouse,
  * and depending on the chosen resolution enable or not the haptic feedback:
  * - a resolution (-r) of 3600 will report 3600 "ticks" in one full rotation
  *   wihout haptic feedback
  * - any other resolution will report N "ticks" in a full rotation with haptic
  *   feedback
  *
@@ -57,7 +57,7 @@ static void usage(const char *prog)
 		"This program will morph the Microsoft Surface Dial into a mouse,\n"
 		"and depending on the chosen resolution enable or not the haptic feedback:\n"
 		"- a resolution (-r) of 3600 will report 3600 'ticks' in one full rotation\n"
-		"  wihout haptic feedback\n"
+		"  without haptic feedback\n"
 		"- any other resolution will report N 'ticks' in a full rotation with haptic\n"
 		"  feedback\n"
 		"\n"
@@ -4,7 +4,7 @@
  * and depending on the chosen resolution enable or not the haptic feedback:
  * - a resolution (-r) of 3600 will report 3600 "ticks" in one full rotation
- *   wihout haptic feedback
+ *   without haptic feedback
  * - any other resolution will report N "ticks" in a full rotation with haptic
  *   feedback
-- 
2.38.1


^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2022-11-21 21:12 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-11-16  9:39 [PATCH][next] samples/hid: Fix spelling mistake "wihout" -> "without" Colin Ian King
2022-11-16 10:32 ` Benjamin Tissoires
2022-11-21 21:12 ` Jiri Kosina

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®